@@ -2,6 +2,10 @@
 
 namespace mixal {
 
+bool Instructions::hasArguments(Instructions::Code code) {
+    return !(code == Instructions::NOP || code == Instructions::HLT);
+}
+
 Instructions::Code Instructions::getInstructionCode(const std::string& name) {
     auto charAt = [&name] (size_t index) -> char {
         return index < name.length() ? std::toupper(name[index]) : '#';
@@ -19,6 +23,16 @@ Instructions::Code Instructions::getInstructionCode(const std::string& name) {
                 break;
             }
             break;
+        case 'L':
+            switch (charAt(2)) {
+            case 'F':
+                switch (charAt(3)) {
+                case '#':
+                    return Instructions::ALF;
+                }
+                break;
+            }
+            break;
         }
         break;
     case 'C':
@@ -179,6 +193,12 @@ Instructions::Code Instructions::getInstructionCode(const std::string& name) {
         switch (charAt(1)) {
         case 'N':
             switch (charAt(2)) {
+            case 'D':
+                switch (charAt(3)) {
+                case '#':
+                    return Instructions::END;
+                }
+                break;
             case 'N':
                 switch (charAt(3)) {
                 case '1':
