@@ -2,6 +2,7 @@
 #include <string>
 #include <iostream>
 #include "memory.h"
+#include "unicode_char.h"
 
 namespace mixal {
 
@@ -15,13 +16,13 @@ uint16_t CHAR_CODES[] = {
 };
 
 bool ComputerWord::operator==(const ComputerWord& word) const {
-    return sign == word.sign && byte1 == word.byte1 &&
+    return negative == word.negative && byte1 == word.byte1 &&
            byte2 == word.byte2 && byte3 == word.byte3 &&
            byte4 == word.byte4 && byte5 == word.byte5;
 }
 
 std::ostream& operator<<(std::ostream& out, const ComputerWord& word) {
-    out << (word.sign ? '-' : '+');
+    out << (word.negative ? '-' : '+');
     for (int i = 1; i <= 5; ++i) {
         out << ' ' << static_cast<int>(word[i]);
     }
@@ -30,7 +31,7 @@ std::ostream& operator<<(std::ostream& out, const ComputerWord& word) {
 
 std::string ComputerWord::getBytesString() const {
     std::string result;
-    result += sign ? '-' : '+';
+    result += negative ? '-' : '+';
     for (int i = 1; i <= 5; ++i) {
         result += ' ';
         if ((*this)[i] < 10) {
@@ -95,21 +96,21 @@ int32_t ComputerWord::value() const {
                     static_cast<int32_t>(byte3 << 12) |
                     static_cast<int32_t>(byte4 << 6) |
                     static_cast<int32_t>(byte5);
-    return sign ? -value : value;
+    return negative ? -value : value;
 }
 
 int16_t ComputerWord::addressValue() const {
     int16_t value = static_cast<int16_t>(this->bytes12());
-    if (sign) {
+    if (negative) {
         value = -value;
     }
     return value;
 }
 
 void ComputerWord::setAddress(int16_t address) {
-    sign = false;
+    negative = false;
     if (address < 0) {
-        sign = true;
+        negative = true;
         address = -address;
     }
     byte1 = static_cast<uint8_t>(address / 64);
@@ -117,7 +118,7 @@ void ComputerWord::setAddress(int16_t address) {
 }
 
 void ComputerWord::setAddress(bool negative, uint16_t address) {
-    sign = negative;
+    this->negative = negative;
     byte1 = static_cast<uint8_t>(address / 64);
     byte2 = static_cast<uint8_t>(address % 64);
 }
@@ -127,11 +128,7 @@ std::string ComputerWord::getCharacters() const {
     for (int i = 1; i <= 5; ++i) {
         if (getAt(i) < CHAR_CODES_NUM) {
             uint16_t code = CHAR_CODES[getAt(i)];
-            if (code < 127) {
-                chars += static_cast<char>(code);
-            } else {
-                chars += ' ';
-            }
+            chars += unicode::toUTF8(static_cast<unicode::UChar>(code));
         } else {
             chars += ' ';
         }
@@ -141,9 +138,9 @@ std::string ComputerWord::getCharacters() const {
 
 void ComputerWord::set(int32_t value) {
     if (value > 0) {
-        sign = 0;
+        negative = false;
     } else if (value < 0) {
-        sign = 1;
+        negative = true;
         value = -value;
     }
     for (int i = 5; i >= 1; --i) {
@@ -153,14 +150,15 @@ void ComputerWord::set(int32_t value) {
 }
 
 void ComputerWord::set(const std::string& chars) {
-    if (chars.length() != 5) {
+    auto codes = unicode::fromUTF8(chars);
+    if (codes.size() != 5) {
         throw std::runtime_error("Invalid length of characters for a word: " + chars);
     }
-    this->sign = false;
+    negative = false;
     for (int i = 0; i < 5; ++i) {
         (*this)[i + 1] = 0;
         for (int j = 0; j < CHAR_CODES_NUM; ++j) {
-            if (static_cast<uint16_t>(chars[i]) == CHAR_CODES[j]) {
+            if (static_cast<uint16_t>(codes[i]) == CHAR_CODES[j]) {
                 (*this)[i + 1] = j;
                 break;
             }
@@ -182,7 +180,7 @@ void ComputerWord::set(int index, uint8_t val) {
 }
 
 void ComputerWord::set(bool negative, uint8_t byte1, uint8_t byte2, uint8_t byte3, uint8_t byte4, uint8_t byte5) {
-    this->sign = static_cast<int>(negative);
+    this->negative = negative;
     this->byte1 = byte1;
     this->byte2 = byte2;
     this->byte3 = byte3;
@@ -191,7 +189,7 @@ void ComputerWord::set(bool negative, uint8_t byte1, uint8_t byte2, uint8_t byte
 }
 
 void ComputerWord::set(bool negative, uint16_t bytes12, uint8_t byte3, uint8_t byte4, uint8_t byte5) {
-    this->sign = static_cast<int>(negative);
+    this->negative = negative;
     this->byte1 = static_cast<uint8_t>(bytes12 / 64);
     this->byte2 = static_cast<uint8_t>(bytes12 % 64);
     this->byte3 = byte3;
